Documentation
¶
Overview ¶
Package nativelib provides platform detection, download, and extraction of the wgpu-native binary library.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Download ¶
Download downloads the file at url to a temporary file and returns its path. The caller is responsible for removing the temporary file when done.
func ExtractLibrary ¶
ExtractLibrary extracts the file named libName from the zip archive at zipPath, writing it to destDir. Returns the path of the extracted file.
func FindLibrary ¶
func FindLibrary() string
func LibraryName ¶
func LibraryName() string
Types ¶
Click to show internal directories.
Click to hide internal directories.